==> meteor-bootstrap_key-value-tag-input-2.4.1.tgz: package/src/keyValueTypes/KeyValueEntry.js <==
var KeyValueEntry = /** @class */ (function () {
    function KeyValueEntry(type) {
        this._value = undefined;
        this._type = type;
    }
    Object.defineProperty(KeyValueEntry.prototype, "type", {
        get: function () {
            return this._type;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "id", {
        get: function () {
            return this._type.id;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "label", {
        get: function () {
            return this._type.label;
        },
        enumerable: true,
        configurable: true
    });
    KeyValueEntry.prototype.getSuggestions = function (prefix) {
        return this._type.getSuggestions(prefix);
    };
    KeyValueEntry.prototype.parse = function (val) {
        if (typeof val === "string") {
            return this._type.parseString(val);
        }
        else if (val !== undefined) {
            return this._type.checkValue(val);
        }
        return undefined;
    };
    KeyValueEntry.prototype.set = function (val) {
        this._value = this.parse(val);
        return this._value !== undefined;
    };
    Object.defineProperty(KeyValueEntry.prototype, "value", {
        get: function () {
            return this._value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "isPartial", {
        get: function () {
            return this.value === undefined;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "display", {
        get: function () {
            if (this.value === undefined) {
                return undefined;
            }
            return this._type.display(this.value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "editText", {
        get: function () {
            if (this.value === undefined) {
                return undefined;
            }
            return this._type.editText(this.value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "constructionData", {
        get: function () {
            return {
                key: this.id,
                value: this.editText,
            };
        },
        enumerable: true,
        configurable: true
    });
    KeyValueEntry.prototype.equals = function (entry) {
        return this._type.isEqual(this, entry);
    };
    return KeyValueEntry;
}());
export { KeyValueEntry };

==> meteor-bootstrap_key-value-tag-input-3.3.0.tgz: package/src/keyValueTypes/KeyValueEntry.js <==
var KeyValueEntry = /** @class */ (function () {
    function KeyValueEntry(type) {
        this._value = undefined;
        this._type = type;
    }
    Object.defineProperty(KeyValueEntry.prototype, "type", {
        get: function () {
            return this._type;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "id", {
        get: function () {
            return this._type.id;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "label", {
        get: function () {
            return this._type.label;
        },
        enumerable: true,
        configurable: true
    });
    KeyValueEntry.prototype.getSuggestions = function (prefix, entries, defaultEntries, allowDuplicates) {
        return this._type.getSuggestions(prefix, entries, defaultEntries, allowDuplicates);
    };
    KeyValueEntry.prototype.parse = function (val) {
        if (typeof val === "string") {
            return this._type.parseString(val);
        }
        else if (val !== undefined) {
            return this._type.checkValue(val);
        }
        return undefined;
    };
    KeyValueEntry.prototype.set = function (val) {
        this._value = this.parse(val);
        return this._value !== undefined;
    };
    Object.defineProperty(KeyValueEntry.prototype, "value", {
        get: function () {
            return this._value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "isPartial", {
        get: function () {
            return this.value === undefined;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "display", {
        get: function () {
            if (this.value === undefined) {
                return undefined;
            }
            return this._type.display(this.value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "editText", {
        get: function () {
            if (this.value === undefined) {
                return undefined;
            }
            return this._type.editText(this.value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyValueEntry.prototype, "constructionData", {
        get: function () {
            return {
                key: this.id,
                value: this.editText,
            };
        },
        enumerable: true,
        configurable: true
    });
    KeyValueEntry.prototype.equals = function (entry) {
        return this._type.isEqual(this, entry);
    };
    return KeyValueEntry;
}());
export { KeyValueEntry };
